@@ -1,4 +1,6 @@
 /*
+ * $Id: psorder.c,v 1.5.16.1 2008/11/25 15:16:31 didg Exp $
+ *
  * Copyright (c) 1990,1991 Regents of The University of Michigan.
  * All Rights Reserved.
  *
@@ -21,25 +23,32 @@
  *	netatalk@itd.umich.edu
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif /* HAVE_CONFIG_H */
+
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/param.h>
-#include <sys/dir.h>
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <sys/uio.h>
 #include <sys/file.h>
 #include <ctype.h>
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif /* HAVE_FCNTL_H */
 #include <stdio.h>
-#include <strings.h>
 #include <string.h>
+#include <dirent.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif /* HAVE_UNISTD_H */
 #include "pa.h"
 #include "psorder.h"
 
 #include <atalk/paths.h>
 
-#define	DEBUG		0
-
 /*
  *			Global Variables
  */
@@ -48,17 +57,15 @@ u_char			psbuf[ 8192 ];
 struct psinfo_st	psinfo;
 int			orderflag, forceflag;
 
-main( argc, argv )
+int main( argc, argv )
     int		argc;
     char	**argv;
 {
-    extern char	*optarg;
-    extern int	optind, opterr;
+    extern int	optind;
     char	*progname;
     int		errflag = 0;
     int		c;
 
-    opterr = 0;
     while (( c = getopt( argc, argv, OPTSTR )) != -1 ) {
 	switch ( c ) {
 	case REVCHAR:
@@ -76,7 +83,7 @@ main( argc, argv )
 	}
     }
     if ( errflag ) {
-	if (( progname = rindex( argv[ 0 ], '/' )) == NULL ) {
+	if (( progname = strrchr( argv[ 0 ], '/' )) == NULL ) {
 	    progname = argv[ 0 ];
 	} else progname++;
 	fprintf( stderr, "usage: %s [-duf] [sourcefile]\n", progname );
@@ -99,7 +106,7 @@ psorder( path )
 
     filesetup( path, &inputfd, tempfile, &tempfd );
     readps( inputfd, tempfd, tempfile );
-    if ( lseek( tempfd, REWIND, L_SET ) < 0 ) {
+    if ( lseek( tempfd, REWIND, SEEK_SET ) < 0 ) {
 	perror( tempfile );
 	filecleanup( -1, tempfd, tempfile );
     }
@@ -138,13 +145,13 @@ filesetup( inputfile, infd, tfile, tfd )
 #if DEBUG
     fprintf( stderr, "Input file or stdin and stdout opened.\n" );
     fprintf( stderr, "Input file descriptor is %d .\n", *infd );
-#endif
+#endif /* DEBUG */
 
 /*
 	make temporary file
  */
 
-    (void *)strncpy( tfile, template, MAXNAMLEN );
+    strncpy( tfile, template, MAXNAMLEN );
     if (( *tfd = mkstemp( tfile )) == -1 ) {
 	fprintf( stderr, "can't create temporary file %s\n", tfile );
 	filecleanup( -1, -1, "" );
@@ -153,7 +160,7 @@ filesetup( inputfile, infd, tfile, tfd )
 #if DEBUG
     fprintf( stderr, "Temporary file %s created and opened.\n", tfile );
     fprintf( stderr, "Temporary file descriptor is %d .\n", *tfd );
-#endif
+#endif /* DEBUG */
 
     psinfo.firstpage = NULL;
     psinfo.lastpage = NULL;
@@ -204,7 +211,7 @@ readps( inputfd, tempfd, tempfile )
     }
 #if DEBUG
     fprintf( stderr, "%s\n", curtok );
-#endif
+#endif /* DEBUG */
 
 /*
  * not postscript
@@ -212,7 +219,7 @@ readps( inputfd, tempfd, tempfile )
     if ( strcmp( curtok, PPSADOBE ) != 0 ) {
 #if DEBUG
     fprintf( stderr, "in the not postscript section of readps\n" );
-#endif
+#endif /* DEBUG */
 	while (( c = pa_getchar( pb )) != 0 ) {
 	    ccread++;
 	    (void)putc( c, tempstream );
@@ -229,7 +236,7 @@ readps( inputfd, tempfd, tempfile )
  */
 #if DEBUG
     fprintf( stderr, "in the postscript section of readps\n" );
-#endif
+#endif /* DEBUG */
     while (( c = pa_getchar( pb )) != 0 ) {
 	ccread++;
 	(void)putc( c, tempstream );
@@ -238,10 +245,10 @@ readps( inputfd, tempfd, tempfile )
 	if ((( pc == '\r' ) || ( pc == '\n' )) && ( cc == '%' )) {
 #if DEBUG
 	    fprintf( stderr, "supposed start of match, cc = %c\n", cc );
-#endif
+#endif /* DEBUG */
 	    pa_match( pb );
 	    ccmatch = ccread - 1;
-	    while ( c = pa_getchar( pb )) {
+	    while ( ( c = pa_getchar( pb ) ) ) {
 		if ( c != 0 ) {
 		    ccread++;
 		    (void)putc( c, tempstream );
@@ -252,7 +259,7 @@ readps( inputfd, tempfd, tempfile )
 		    curtok = pa_gettok( pb );
 #if DEBUG
 		    fprintf( stderr, "%s\n", curtok );
-#endif
+#endif /* DEBUG */
 		    if ( handletok( ccmatch, curtok ) < 0 ) {
 			perror( "malloc died" );
 			filecleanup( -1, tempfd, tempfile );
@@ -282,19 +289,19 @@ handletok( count, token )
 	incdoc--;
 #if DEBUG
 	fprintf( stderr, "found an EndDoc\n" );
-#endif
+#endif /* DEBUG */
 
     } else if ( strncmp( PBEGINDOC, token, strlen( PBEGINDOC )) == 0 ) {
 	incdoc++;
 #if DEBUG
 	fprintf( stderr, "found a BeginDoc\n" );
-#endif
+#endif /* DEBUG */
 
     } else if ( !incdoc && 
 	    ( strncmp( PPAGE, token, strlen( PPAGE )) == 0 )) {
 #if DEBUG
 	fprintf( stderr, "found a Page\n" );
-#endif
+#endif /* DEBUG */
 	if (( newpage = getpspage( count )) == NULL ) {
 	    return( -1 );
 	}
@@ -316,13 +323,13 @@ handletok( count, token )
 #if DEBUG
 	fprintf( stderr, "page lable %s, page ord %s\n", newpage->lable,
 		newpage->ord );
-#endif
+#endif /* DEBUG */
 
     } else if ( !incdoc && 
 	    ( strncmp( PPAGES, token, strlen( PPAGES )) == 0 )) {
 #if DEBUG
 	fprintf( stderr, "found a Pages\n" );
-#endif
+#endif /* DEBUG */
 	psinfo.pages.offset = count;
 	psinfo.pages.end = strlen( token ) + count;
 	while ( *token++ != ':' );
@@ -330,7 +337,7 @@ handletok( count, token )
 	if ( strncmp( ATEND, token, strlen( ATEND )) == 0 ) {
 #if DEBUG
 	    fprintf( stderr, "it is a Pages: (atend)\n" );
-#endif
+#endif /* DEBUG */
 	    psinfo.pages.offset = 0;
 	    psinfo.pages.end = 0;
 	} else {
@@ -343,14 +350,14 @@ handletok( count, token )
 #if DEBUG
 	    fprintf( stderr, "number of pages %s\n", psinfo.pages.num );
 	    fprintf( stderr, "order control number %s\n", psinfo.pages.order );
-#endif
+#endif /* DEBUG */
 	}
 
     } else if ( !incdoc && 
 	    ( strncmp( PTRAILER, token, strlen( PTRAILER )) == 0 )) {
 #if DEBUG
 	fprintf( stderr, "found the Trailer\n" );
-#endif
+#endif /* DEBUG */
 	if  ( psinfo.trailer == 0 ) {
 	    psinfo.trailer = count;
 	}
@@ -407,7 +414,7 @@ writeps( tempfd, tempfile )
 		    ( psinfo.pages.offset != 0 )) {
 		temp2out( tempfd, tempfile, psinfo.pages.offset );
 		writelable( tempfd, tempfile, PPAGES );
-		if ( lseek( tempfd, psinfo.pages.end, L_SET ) < 0 ) {
+		if ( lseek( tempfd, psinfo.pages.end, SEEK_SET ) < 0 ) {
 		    perror( tempfile );
 		    filecleanup( -1, tempfd, tempfile );
 		}
@@ -419,7 +426,7 @@ writeps( tempfd, tempfile )
  *	output the pages, last to first
  */
 	while ( psinfo.lastpage != NULL ) {
-	    if ( lseek( tempfd, psinfo.lastpage->offset, L_SET ) < 0 ) {
+	    if ( lseek( tempfd, psinfo.lastpage->offset, SEEK_SET ) < 0 ) {
 		perror( tempfile );
 		filecleanup( -1, tempfd, tempfile );
 	    }
@@ -436,7 +443,7 @@ writeps( tempfd, tempfile )
  *	if it is in the trailer
  */
 	if ( psinfo.trailer != 0 ) {
-	    if ( lseek( tempfd, psinfo.trailer, L_SET ) < 0 ) {
+	    if ( lseek( tempfd, psinfo.trailer, SEEK_SET ) < 0 ) {
 		perror( tempfile );
 		filecleanup( -1, tempfd, tempfile );
 	    }
@@ -444,7 +451,7 @@ writeps( tempfd, tempfile )
 		temp2out( tempfd, tempfile,
 			psinfo.pages.offset - psinfo.trailer );
 		writelable( tempfd, tempfile, PPAGES );
-		if ( lseek( tempfd, psinfo.pages.end, L_SET ) < 0 ) {
+		if ( lseek( tempfd, psinfo.pages.end, SEEK_SET ) < 0 ) {
 		    perror( tempfile );
 		    filecleanup( -1, tempfd, tempfile );
 		}
